@@ -542,6 +542,11 @@ class SlabAdsorbateCoverage(object):
         The surface type (crystal structure + Miller indices).
         Required if adsorption_sites is not provided.
 
+    both_sides : bool, default False
+        Whether to consider adsorbate coverage on both top and bottom 
+        sides of the slab. Only works if adsorption_sites is not provided,
+        otherwise consistent with what is specified in adsorption_sites.
+
     label_occupied_sites : bool, default False
         Whether to assign a label to the occupied each site. The string 
         of the occupying adsorbate is concatentated to the numerical 
@@ -590,6 +595,7 @@ class SlabAdsorbateCoverage(object):
     def __init__(self, atoms, 
                  adsorption_sites=None, 
                  surface=None, 
+                 both_sides=False,
                  label_occupied_sites=False,
                  dmax=2.5):
 
@@ -608,6 +614,7 @@ class SlabAdsorbateCoverage(object):
         self.cell = atoms.cell
         self.pbc = atoms.pbc
 
+        self.both_sides = both_sides
         self.label_occupied_sites = label_occupied_sites
         self.dmax = dmax
 
@@ -619,12 +626,14 @@ class SlabAdsorbateCoverage(object):
         else:
             sas = SlabAdsorptionSites(atoms, surface, 
                                       allow_6fold=True,
-                                      composition_effect=True)    
+                                      composition_effect=True,
+                                      both_sides=both_sides)    
         self.sas = sas
         self.slab_ids = sas.indices
         self.surface = sas.surface
         self.allow_6fold = sas.allow_6fold
         self.composition_effect = sas.composition_effect
+        self.both_sides = sas.both_sides
 
         self.metals = sas.metals
         if len(self.metals) == 1 and self.composition_effect:
